@@ -3,11 +3,9 @@
 from guniflask.beans.definition_registry import BeanDefinitionRegistry
 from guniflask.beans.definition import BeanDefinition
 from guniflask.context.config_post_processor import ConfigurationClassPostProcessor
-from guniflask.beans.autowired_post_processor import AutowiredAnnotationBeanPostProcessor
+from guniflask.context.autowired_post_processor import AutowiredAnnotationBeanPostProcessor
 from guniflask.context.config_constants import *
 
-__all__ = ['AnnotationConfigUtils']
-
 
 class AnnotationConfigUtils:
 
