@@ -3,11 +3,9 @@
 from guniflask.beans.definition import BeanDefinition
 from guniflask.beans.definition_registry import BeanDefinitionRegistry
 from guniflask.beans.name_generator import DefaultBeanNameGenerator, BeanNameGenerator
-from guniflask.annotation.core import AnnotationUtils
+from guniflask.annotation import AnnotationUtils
 from guniflask.context.annotation import Component
 
-__all__ = ['AnnotationBeanNameGenerator']
-
 
 class AnnotationBeanNameGenerator(BeanNameGenerator):
     def __init__(self):
@@ -23,7 +21,7 @@ class AnnotationBeanNameGenerator(BeanNameGenerator):
                 if name is not None:
                     if bean_name is not None and name != bean_name:
                         raise ValueError('Annotations suggest inconsistent component names: '
-                                         '"{}" versus {}'.format(bean_name, name))
+                                         f'"{bean_name}" versus {name}')
                     bean_name = name
         if bean_name is not None:
             return bean_name
