@@ -9,12 +9,10 @@ from guniflask.security.context import SecurityContext
 from guniflask.oauth2.authentication_details import OAuth2AuthenticationDetails
 from guniflask.security.authentication_token import AuthenticationToken
 
-__all__ = ['OAuth2AuthenticationFilter']
-
 
 class OAuth2AuthenticationFilter(RequestFilter):
-    def __init__(self):
-        self.authentication_manager: AuthenticationManager = None
+    def __init__(self, authentication_manager: AuthenticationManager):
+        self.authentication_manager = authentication_manager
         self.token_extractor: TokenExtractor = BearerTokenExtractor()
 
     def before_request(self):
