@@ -1,11 +1,7 @@
 # coding=utf-8
 
 import re
-from typing import Optional, Dict
-
-from flask import request
-
-__all__ = ['OAuth2Utils']
+from typing import Optional
 
 
 class OAuth2Utils:
@@ -33,10 +29,3 @@ class OAuth2Utils:
         if not value:
             return None
         return ' '.join(value)
-
-    @staticmethod
-    def get_request_parameters() -> Dict[str, str]:
-        result = {}
-        for k in request.args:
-            result[k] = request.args.get(k)
-        return result
