@@ -9,8 +9,6 @@ from guniflask.security.preauth_token import PreAuthenticatedToken
 from guniflask.oauth2.token import OAuth2AccessToken
 from guniflask.oauth2.authentication_details import OAuth2AuthenticationDetails
 
-__all__ = ['TokenExtractor', 'BearerTokenExtractor']
-
 
 class TokenExtractor(metaclass=ABCMeta):
     @abstractmethod
@@ -38,3 +36,4 @@ class BearerTokenExtractor(TokenExtractor):
         token = request.args.get(OAuth2AccessToken.ACCESS_TOKEN)
         if token is not None:
             g.setdefault(OAuth2AuthenticationDetails.ACCESS_TOKEN_TYPE, OAuth2AccessToken.BEARER_TYPE)
+            return token
