@@ -4,9 +4,7 @@ import datetime as dt
 
 import sqlalchemy
 
-from guniflask.utils.instantiation import string_to_datetime
-
-__all__ = ['model_to_dict', 'result_to_dict', 'dict_to_model', 'update_model_by_dict']
+from guniflask.utils.datatime import string_to_datetime
 
 
 def model_to_dict(model, ignore=None, only=None, only_not_none=False):
