@@ -3,8 +3,6 @@
 from abc import ABCMeta, abstractmethod
 from typing import Any
 
-__all__ = ['SecurityBuilder', 'AbstractSecurityBuilder']
-
 
 class SecurityBuilder(metaclass=ABCMeta):
     @abstractmethod
@@ -16,7 +14,7 @@ class AbstractSecurityBuilder(SecurityBuilder, metaclass=ABCMeta):
     def __init__(self):
         self._object: Any = None
 
-    def build(self):
+    def build(self) -> Any:
         self._object = self._do_build()
         return self._object
 
