@@ -2,13 +2,11 @@
 
 from abc import ABCMeta, abstractmethod
 
-from guniflask.security_config.security_configurer import SecurityConfigurerAdapter
+from guniflask.security_config.security_configurer import SecurityConfigurer
 from guniflask.security.user_details_service import UserDetailsService
 
-__all__ = ['UserDetailsAwareConfigurer']
 
-
-class UserDetailsAwareConfigurer(SecurityConfigurerAdapter, metaclass=ABCMeta):
+class UserDetailsAwareConfigurer(SecurityConfigurer, metaclass=ABCMeta):
     @property
     @abstractmethod
     def user_details_service(self) -> UserDetailsService:
