@@ -3,12 +3,10 @@
 from typing import List
 
 from guniflask.context.annotation import configuration
-from guniflask.beans.factory_hook import SmartInitializingSingleton
+from guniflask.beans.lifecycle import SmartInitializingSingleton
 from guniflask.security_config.web_security_configurer import WebSecurityConfigurer
 from guniflask.security_config.web_security import WebSecurity
 
-__all__ = ['WebSecurityConfiguration']
-
 
 @configuration
 class WebSecurityConfiguration(SmartInitializingSingleton):
