@@ -8,16 +8,14 @@ from guniflask.security_config.authentication_manager_builder import Authenticat
 from guniflask.security.authentication_manager import AuthenticationManager
 from guniflask.security_config.http_security import HttpSecurity
 from guniflask.security_config.authentication_config import AuthenticationConfiguration
-from guniflask.beans.annotation import autowired
-from guniflask.security_config.security_configurer import SecurityConfigurerAdapter
+from guniflask.context.annotation import autowired
+from guniflask.security_config.security_configurer import SecurityConfigurer
 from guniflask.security_config.web_security import WebSecurity
 from guniflask.security.user_details_service import UserDetailsService
 from guniflask.context.bean_context import BeanContext, BeanContextAware
 
-__all__ = ['WebSecurityConfigurer']
 
-
-class WebSecurityConfigurer(SecurityConfigurerAdapter, BeanContextAware):
+class WebSecurityConfigurer(SecurityConfigurer, BeanContextAware):
     def __init__(self):
         super().__init__()
         self._authentication_configuration: AuthenticationConfiguration = None
