@@ -2,39 +2,29 @@
 
 from functools import update_wrapper
 import inspect
-from typing import List
 
-from flask import Blueprint as FlaskBlueprint, request, current_app, g
+from flask import Blueprint as FlaskBlueprint, request, current_app
 from werkzeug.exceptions import BadRequest, InternalServerError
 from werkzeug.routing import parse_rule
+from starlette.websockets import WebSocketDisconnect
 
-from guniflask.web.request_filter import RequestFilter, RequestFilterChain
-from guniflask.beans.constructor_resolver import ConstructorResolver
-from guniflask.web.filter_annotation import FilterChain
-from guniflask.annotation.core import AnnotationUtils
-from guniflask.beans.post_processor import BeanPostProcessorAdapter
-from guniflask.web.bind_annotation import Blueprint, Route
-from guniflask.utils.instantiation import instantiate_from_json, inspect_args
-from guniflask.web.param_annotation import FieldInfo, RequestParam, PathVariable, \
-    RequestParamInfo, PathVariableInfo, RequestBodyInfo, ContextParamInfo
+from guniflask.annotation import AnnotationUtils
+from guniflask.beans.post_processor import BeanPostProcessor
+from guniflask.web.bind_annotation import Blueprint, Route, WebSocket
+from guniflask.utils.inspect import inspect_args
+from guniflask.utils.request import map_object
+from guniflask.web.param_annotation import FieldInfo, RequestParam, PathVariable, RequestParamInfo, PathVariableInfo, \
+    RequestBodyInfo, FilePartInfo, FormValueInfo, RequestHeaderInfo, CookieValueInfo, RequestBody
 from guniflask.web import param_annotation
-from guniflask.beans.factory import BeanFactory, BeanFactoryAware
 from guniflask.context.event_listener import ApplicationEventListener
 from guniflask.context.event import ContextRefreshedEvent, ApplicationEvent
-from guniflask.web.filter_annotation import MethodFilter
-from guniflask.utils.instantiation import resolve_arg_type, ArgType
-
-__all__ = ['BlueprintPostProcessor']
+from guniflask.web.filter_annotation import MethodDefFilter
+from guniflask.utils.inspect import resolve_arg_type, ArgType
 
 
-class BlueprintPostProcessor(BeanPostProcessorAdapter, ApplicationEventListener, BeanFactoryAware):
+class BlueprintPostProcessor(BeanPostProcessor, ApplicationEventListener):
     def __init__(self):
         self.blueprints = []
-        self._filter_chain_resolver: FilterChainResolver = None
-        self._method_filter_resolver = MethodFilterResolver()
-
-    def set_bean_factory(self, bean_factory: BeanFactory):
-        self._filter_chain_resolver = FilterChainResolver(bean_factory)
 
     def on_application_event(self, application_event: ApplicationEvent):
         if isinstance(application_event, ContextRefreshedEvent):
@@ -50,19 +40,24 @@ class BlueprintPostProcessor(BeanPostProcessorAdapter, ApplicationEventListener,
             annotation['blueprint'] = b
             for m in dir(bean):
                 method = getattr(bean, m)
-                a = AnnotationUtils.get_annotation(method, Route)
-                if a is not None:
-                    rule_options = a['options'] or {}
-                    b.add_url_rule(a['rule'],
-                                   endpoint=method.__name__,
-                                   view_func=self.wrap_view_func(a['rule'], method),
-                                   **rule_options)
-                self._method_filter_resolver.resolve(b, method)
+                self._resolve_route(b, method)
+                self._resolve_websocket_route(b, method)
+                self._resolve_method_def_filter(b, method)
             self.blueprints.append(b)
-            self._filter_chain_resolver.add_blueprint(bean_type)
         return bean
 
-    def wrap_view_func(self, rule: str, method):
+    def _resolve_route(self, blueprint: FlaskBlueprint, method):
+        a = AnnotationUtils.get_annotation(method, Route)
+        if a is not None:
+            rule_options = a['options'] or {}
+            blueprint.add_url_rule(
+                a['rule'],
+                endpoint=method.__name__,
+                view_func=self._wrap_view_func(a['rule'], method),
+                **rule_options
+            )
+
+    def _wrap_view_func(self, rule: str, method):
         params, param_names = self._resolve_method_parameters(rule, method)
 
         def wrapper(**kwargs):
@@ -71,9 +66,39 @@ class BlueprintPostProcessor(BeanPostProcessorAdapter, ApplicationEventListener,
 
         return update_wrapper(wrapper, method)
 
-    def _register_blueprints(self):
-        self._filter_chain_resolver.build()
+    def _resolve_websocket_route(self, blueprint: FlaskBlueprint, method):
+        a = AnnotationUtils.get_annotation(method, WebSocket)
+        if a is not None:
+            rule = a['rule'] or '/'
+            rule_prefix = blueprint.url_prefix or '/'
+            rule = '/'.join((rule_prefix.rstrip('/'), rule.lstrip('/')))
+            current_app.asgi_app.add_websocket_route(rule, self._wrap_websocket_func(method))
 
+    def _wrap_websocket_func(self, method):
+        app = current_app._get_current_object()
+
+        async def wrapper(*args, **kwargs):
+            with app.app_context():
+                try:
+                    return await method(*args, **kwargs)
+                except WebSocketDisconnect:
+                    pass
+
+        return update_wrapper(wrapper, method)
+
+    def _resolve_method_def_filter(self, blueprint, method):
+        a = AnnotationUtils.get_annotation(method, MethodDefFilter)
+        if a is None:
+            return
+        for v in a['values']:
+            name = v['name']
+            args = v['args']
+            if args is None:
+                getattr(blueprint, name)(method)
+            else:
+                getattr(blueprint, name)(*args)(method)
+
+    def _register_blueprints(self):
         for b in self.blueprints:
             current_app.register_blueprint(b)
 
@@ -111,7 +136,15 @@ class BlueprintPostProcessor(BeanPostProcessorAdapter, ApplicationEventListener,
                 if arg in path_variable_type:
                     annotation = PathVariable(dtype=None if arg in type_hints else path_variable_type[arg])
                 else:
-                    annotation = RequestParam()
+                    if arg in type_hints:
+                        arg_type = type_hints[arg]
+                        argc, etype = resolve_arg_type(arg_type)
+                        if argc is ArgType.DICT:
+                            annotation = RequestBody()
+                        else:
+                            annotation = RequestParam()
+                    else:
+                        annotation = RequestParam()
                 annotation.default = default
                 default = annotation
             if arg in type_hints and default.dtype is None:
@@ -135,7 +168,7 @@ class BlueprintPostProcessor(BeanPostProcessorAdapter, ApplicationEventListener,
             if k in param_names:
                 k = param_names[k]
             if k not in params:
-                raise InternalServerError('Unhandled parameter: {}={}'.format(k, v))
+                raise InternalServerError(f'Unhandled parameter: {k}={v}')
             if params[k].dtype is not None:
                 try:
                     v = params[k].dtype(v)
@@ -147,7 +180,7 @@ class BlueprintPostProcessor(BeanPostProcessorAdapter, ApplicationEventListener,
                 continue
             name = p.name or k
             if isinstance(p, PathVariableInfo):
-                raise InternalServerError('No such path variable: {}'.format(name))
+                raise InternalServerError(f'No such path variable: {name}')
 
             if isinstance(p, RequestParamInfo):
                 if name in request.args:
@@ -158,31 +191,71 @@ class BlueprintPostProcessor(BeanPostProcessorAdapter, ApplicationEventListener,
                             for i in range(len(v)):
                                 v[i] = self._read_value(v[i], etype)
                     elif argc is ArgType.SINGLE:
-                        v = request.args[name]
+                        v = request.args.get(name)
                         if p.dtype is not None:
                             v = self._read_value(v, p.dtype)
                     else:
-                        raise ValueError('Unsupported request param type: {}'.format(p.dtype))
-
+                        raise BadRequest(f'Unsupported type of parameter "{name}": {p.dtype}')
                     if v is not None:
                         result[k] = v
-            elif isinstance(p, ContextParamInfo):
-                name = p.name or k
-                if name in g:
-                    result[k] = g.get(name)
             elif isinstance(p, RequestBodyInfo):
-                # FIXME: handle files, multi-parts, etc.
                 data = request.json
-                v = instantiate_from_json(data, dtype=p.dtype)
+                v = map_object(data, dtype=p.dtype)
                 if v is not None:
                     result[k] = v
+            elif isinstance(p, FilePartInfo):
+                file = request.files.get(name)
+                if file is not None:
+                    if p.dtype == bytes:
+                        result[k] = file.read()
+                    else:
+                        result[k] = file
+            elif isinstance(p, FormValueInfo):
+                argc, etype = resolve_arg_type(p.dtype)
+                if argc is ArgType.LIST:
+                    v = request.form.getlist(name)
+                    if etype:
+                        for i in range(len(v)):
+                            v[i] = self._read_value(v[i], etype)
+                elif argc is ArgType.SINGLE:
+                    v = request.form.get(name)
+                    if p.dtype is not None:
+                        v = self._read_value(v, p.dtype)
+                else:
+                    raise BadRequest(f'Unsupported type of parameter "{name}": {p.dtype}')
+                if v is not None:
+                    result[k] = v
+            elif isinstance(p, RequestHeaderInfo):
+                argc, etype = resolve_arg_type(p.dtype)
+                if argc is ArgType.LIST:
+                    v = request.headers.getlist(name)
+                    if etype:
+                        for i in range(len(v)):
+                            v[i] = self._read_value(v[i], etype)
+                elif argc is ArgType.SINGLE:
+                    v = request.headers.get(name)
+                    if p.dtype is not None:
+                        v = self._read_value(v, p.dtype)
+                else:
+                    raise BadRequest(f'Unsupported type of header "{name}": {p.dtype}')
+                if v is not None:
+                    result[k] = v
+                v = self._read_value(request.headers.get(name), p.dtype)
+                if v is not None:
+                    result[k] = v
+            elif isinstance(p, CookieValueInfo):
+                v = request.cookies.get(name)
+                if v is not None:
+                    if p.dtype is not None:
+                        v = self._read_value(v, p.dtype)
+                    result[k] = v
 
             if k not in result:
                 if p.required:
                     if isinstance(p, RequestBodyInfo):
                         raise BadRequest('Request body not given or in wrong format')
                     else:
-                        raise BadRequest('Parameter not given: {}'.format(name))
+                        raise BadRequest(f'Parameter not given: {name}')
                 result[k] = p.default
         return result
 
@@ -201,56 +274,4 @@ class BlueprintPostProcessor(BeanPostProcessorAdapter, ApplicationEventListener,
             try:
                 return dtype(v)
             except (ValueError, TypeError):
-                pass
-
-
-class FilterChainResolver:
-    def __init__(self, bean_factory: BeanFactory):
-        self._constructor_resolver = ConstructorResolver(bean_factory)
-        self._blueprints = []
-
-    def add_blueprint(self, bean_type):
-        self._blueprints.append(bean_type)
-
-    def build(self):
-        for bean_type in self._blueprints:
-            filter_chain_annotation = AnnotationUtils.get_annotation(bean_type, FilterChain)
-            if filter_chain_annotation is not None:
-                request_filters = self._resolve_request_filters(filter_chain_annotation['values'])
-                if request_filters:
-                    chain = RequestFilterChain()
-                    for f in request_filters:
-                        chain.add_request_filter(f)
-
-                    blueprint_annotation = AnnotationUtils.get_annotation(bean_type, Blueprint)
-                    b = blueprint_annotation['blueprint']
-                    b.before_request(chain.before_request)
-                    b.after_request(chain.after_request)
-
-    def _resolve_request_filters(self, values) -> List[RequestFilter]:
-        if not hasattr(values, '__iter__'):
-            values = [values]
-        result = []
-        for v in values:
-            if isinstance(v, RequestFilter):
-                result.append(v)
-            else:
-                f = self._constructor_resolver.instantiate(v)
-                assert isinstance(f, RequestFilter), 'Required a request filter, ' \
-                                                     'got: {}'.format(type(RequestFilter).__name__)
-        return result
-
-
-class MethodFilterResolver:
-
-    def resolve(self, blueprint, method):
-        a = AnnotationUtils.get_annotation(method, MethodFilter)
-        if a is None:
-            return
-        for v in a['values']:
-            name = v['name']
-            args = v['args']
-            if args is None:
-                getattr(blueprint, name)(method)
-            else:
-                getattr(blueprint, name)(*args)(method)
+                raise BadRequest(f'The expected type is "{dtype.__name__}": {v}')
